aboutsummaryrefslogtreecommitdiff
path: root/gas/config
diff options
context:
space:
mode:
authormfortune <matthew.fortune@imgtec.com>2014-05-20 12:45:47 +0100
committermfortune <matthew.fortune@imgtec.com>2014-05-20 23:05:03 +0100
commit82bda27b2f439498b5c8b4941d8d47bdfe916688 (patch)
tree78195a68338324187d2ccd5ef127dd649a752e1e /gas/config
parent865d0aef3a841c9c5b11a0fa05066ed97b1850fe (diff)
downloadgdb-82bda27b2f439498b5c8b4941d8d47bdfe916688.zip
gdb-82bda27b2f439498b5c8b4941d8d47bdfe916688.tar.gz
gdb-82bda27b2f439498b5c8b4941d8d47bdfe916688.tar.bz2
Mark MSA as requiring FP64
gas/ * config/tc-mips.c (FP64_ASES): Add ASE_MSA. (mips_after_parse_args): Do not select ASE_MSA without -mfp64. gas/testsuite/ * gas/mips/micromips@msa-branch.d: Rework expected output for fp64. * gas/mips/msa-branch.d: Likewise.
Diffstat (limited to 'gas/config')
-rw-r--r--gas/config/tc-mips.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gas/config/tc-mips.c b/gas/config/tc-mips.c
index 95ffe50..dbf9c6e 100644
--- a/gas/config/tc-mips.c
+++ b/gas/config/tc-mips.c
@@ -1643,7 +1643,7 @@ static const struct mips_ase mips_ases[] = {
};
/* The set of ASEs that require -mfp64. */
-#define FP64_ASES (ASE_MIPS3D | ASE_MDMX)
+#define FP64_ASES (ASE_MIPS3D | ASE_MDMX | ASE_MSA)
/* Groups of ASE_* flags that represent different revisions of an ASE. */
static const unsigned int mips_ase_groups[] = {
@@ -14021,7 +14021,7 @@ mips_after_parse_args (void)
file_mips_opts.fp = 64;
else if ((mips_opts.ase & FP64_ASES)
&& ISA_HAS_64BIT_FPRS (mips_opts.isa))
- /* -mips3d and -mdmx imply 64-bit float registers, if possible. */
+ /* Handle ASEs that require 64-bit float registers, if possible. */
file_mips_opts.fp = 64;
else
/* 32-bit float registers. */
@@ -14063,10 +14063,10 @@ mips_after_parse_args (void)
mips_opts.micromips = (CPU_HAS_MICROMIPS (file_mips_opts.arch))
? 1 : 0;
/* MIPS3D and MDMX require 64-bit FPRs, so -mfp32 should stop those
ASEs from being selected implicitly. */
if (file_mips_opts.fp != 64)
- file_ase_explicit |= ASE_MIPS3D | ASE_MDMX;
+ file_ase_explicit |= ASE_MIPS3D | ASE_MDMX | ASE_MSA;
/* If the user didn't explicitly select or deselect a particular ASE,
use the default setting for the CPU. */
@@ -14063,10 +14063,10 @@ mips_after_parse_args (void)
mips_opts.micromips = (CPU_HAS_MICROMIPS (file_mips_opts.arch))
? 1 : 0;
- /* MIPS3D and MDMX require 64-bit FPRs, so -mfp32 should stop those
+ /* MIPS3D, MDMX and MSA require 64-bit FPRs, so -mfp32 should stop those
ASEs from being selected implicitly. */
if (file_mips_opts.fp != 64)